OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Senhal incorrècte",
    "No user supplied" : "Cap d'utilizaire pas provesit",
    "Authentication error" : "Error d'autentificacion",
    "Wrong admin recovery password. Please check the password and try again." : "Senhal administrator de recuperacion de donadas pas valable. Verificatz lo senhal e ensajar tornamai.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "L'infrastructura de rèire plan supòrta pas la modification de senhal, mas la clau de chiframent de l'utilizaire es estada mesa a jorn amb succès.",
    "Unable to change password" : "Impossible de modificar lo senhal",
    "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "lo partiment Federated Cloud o l'installacion e la mesa a jorn d'aplicacions per l'app store",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL utiliza %s version (%s), qu'es una version obsolèta. Metètz a jorn vòstre sistèma operatiu, o de foncionalitats talas coma %s foncionaràn pas corrèctament.",
    "A problem occurred, please check your log files (Error: %s)" : "Una error s'es produsida, verificatz vòstres fichièrs de log (Error: %s)",
    "Migration Completed" : "Migracion acabada",
    "Group already exists." : "Aqueste grop existís ja.",
    "Unable to add group." : "Impossible d'apondre lo grop.",
    "Unable to delete group." : "Impossible de suprimir lo grop.",
    "log-level out of allowed range" : "nivèl de jornalizacion fòra bòrna",
    "Saved" : "Salvat",
    "test email settings" : "testar los paramètres d'e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Una error s'es produsida al moment del mandadís de l'e-mail. Verificatz vòstres paramètres. (Error: %s)",
    "Email sent" : "Email mandat",
    "You need to set your user email before being able to send test emails." : "Vos cal especificar vòstra adreça email dins los paramètres personals abans de poder mandar d'emails de tèst.",
    "Invalid mail address" : "Adreça email invalida",
    "A user with that name already exists." : "Un utilizaire amb aqueste nom existís ja.",
    "Unable to create user." : "Impossible de crear l'utilizaire.",
    "Your %s account was created" : "Vòstre compte %s es estat creat.",
    "Unable to delete user." : "Impossible de suprimir l'utilizaire.",
    "Forbidden" : "Interdich",
    "Invalid user" : "Utilizaire invalid",
    "Unable to change mail address" : "Impossible de modificar l'adreça de corrièl",
    "Your full name has been changed." : "Vòstre nom complet es estat modificat.",
    "Unable to change full name" : "Impossible de cambiar lo nom complet",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Occitan-lengadocian",
    "Language changed" : "Lenga cambiada",
    "Invalid request" : "Requèsta invalida",
    "Admins can't remove themself from the admin group" : "Los administrators se pòdon pas levar eles-meteisses del grop admin",
    "Unknown user" : "Utilizaire desconegut",
    "Couldn't remove app." : "Impossible de suprimir l'aplicacion.",
    "Official" : "Oficial",
    "Approved" : "Aprovat",
    "All" : "Totes",
    "Enabled" : "Activadas",
    "Not enabled" : "Desactivadas",
    "No apps found for your version" : "Pas d'aplicacion trobada per vòstra version",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Las aplicacions oficialas son desvolopadas per e amb la comunautat ownCloud. Ofrisson sas foncionalitats principalas a ownCloud e son prèstas per una utilizacion en produccion. ",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Las aplicacions aprovadas son creadas per de desvolopaires de fisança e an passat los tèst de seguretat. Son activament mantengudas dins un depaus dobèrt e lors desvolopaires pensan que son establas per una utilizacion normala.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Aquesta aplicacion es novèla o instabla, e sa seguretat es pas estada verificada. Installatz-la a vòstras riscas e perilhs !",
    "Please wait...." : "Pacientatz…",
    "Error while disabling app" : "Error al moment de la desactivacion de l'aplicacion",
    "Disable" : "Desactivar",
    "Enable" : "Activar",
    "Error while enabling app" : "Error al moment de l'activacion de l'aplicacion",
    "Updating...." : "Mesa a jorn...",
    "Error while updating app" : "Error al moment de la mesa a jorn de l'aplicacion",
    "Updated" : "Mesa a jorn efectuada",
    "Uninstalling ...." : "Desinstallacion...",
    "Error while uninstalling app" : "Error al moment de la desinstallacion de l'aplicacion",
    "Uninstall" : "Desinstallar",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicacion es estada activada mas deu èsser mesa a jorn. Seretz redirigit cap a la pagina de las mesas a jorn dins 5 segondas.",
    "App update" : "Mesa a jorn",
    "Experimental" : "Experimental",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sètz segur que volètz apondre \"{domain}\" coma domeni de fisança ?",
    "Add trusted domain" : "Apondre un domeni de fisança",
    "Migration in progress. Please wait until the migration is finished" : "Migracion en cors. Esperatz qu'aquela s'acabe",
    "Migration started …" : "Migracion aviada...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Una error s'es produsida. Provesissètz un certificat PEM encodat al format ASCII.",
    "Valid until {date}" : "Valid fins al {date}",
    "Delete" : "Suprimir",
    "Sending..." : "Mandadís en cors...",
    "An error occurred: {message}" : "Una error s'es produsida : {message}",
    "Select a profile picture" : "Seleccionar una fòto de perfil ",
    "Very weak password" : "Senhal de fòrt febla seguretat",
    "Weak password" : "Senhal de febla seguretat",
    "So-so password" : "Senhal de seguretat tot bèl juste acceptable",
    "Good password" : "Senhal de seguretat sufisenta",
    "Strong password" : "Senhal de fòrta seguretat",
    "Groups" : "Gropes",
    "Unable to delete {objName}" : "Impossible de suprimir {objName}",
    "A valid group name must be provided" : "Vos cal especificar un nom de grop valid",
    "deleted {groupName}" : "{groupName} suprimit",
    "undo" : "anullar",
    "never" : "pas jamai",
    "deleted {userName}" : "{userName} suprimit",
    "add group" : "apondre un grop",
    "enabled" : "activat",
    "disabled" : "desactivat",
    "no group" : "Pas cap de grop",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "La modificacion del senhal entraïnarà la pèrta de las donadas perque lo restabliment de donadas es pas disponible per aqueste utilizaire",
    "A valid username must be provided" : "Un nom d'utilizaire valid deu èsser picat",
    "A valid password must be provided" : "Un senhal valid deu èsser picat",
    "A valid email must be provided" : "Vos cal provesir una adreça de corrièl valida",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Bonjorn,<br><br>Un compte %s es estat creat per vos.<br><br>Vòstre nom d'utilizaire es : %s<br>Visitatz vòstre compte : <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "A lèu !",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Bonjorn,<br><br>Un compte %s es estat creat per vos.<br><br>Vòstre nom d'utilizaire es : %s<br>Visitatz vòstre compte : %s<br><br>\n",
    "User documentation" : "Documentacion utilizaire",
    "Administrator documentation" : "Documentacion administrator",
    "Online documentation" : "Documentacion en linha",
    "Forum" : "Forum",
    "Issue tracker" : "Seguiment de problèmas",
    "Commercial support" : "Supòrt comercial",
    "Developer documentation" : "Documentacion pels desvolopaires",
    "Documentation:" : "Documentacion :",
    "Admin documentation" : "Documentacion administrator",
    "Report a bug" : "Raportar un bug",
    "Show description …" : "Afichar la descripcion...",
    "Hide description …" : "Amagar la descripcion...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicacion pòt pas èsser installada a causa d'aquelas dependéncias pas satisfachas :",
    "Enable only for specific groups" : "Activar unicament per certans gropes",
    "Uninstall App" : "Desinstallar l'aplicacion",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Darrièr prètzfach cron d'executat : %s.",
    "Last cron job execution: %s. Something seems wrong." : "Darrièr prètzfach cron d'executat : %s. Quicòm a trucat.",
    "Cron was not executed yet!" : "Lo cron es pas encara estat executat !",
    "Open documentation" : "Veire la documentacion",
    "Execute one task with each page loaded" : "Executa un prètzfach a cada cargament de pagina",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php es enregistrat alprèp d'un servici webcron que l'executarà a cada 15 minutas via http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Utilizatz lo servici cron del sistèma per apelar lo fichièr cron.php a cada 15 minutas.",
    "Common Name" : "Nom d'usatge",
    "Valid until" : "Valid fins a",
    "Issued By" : "Desliurat per",
    "Valid until %s" : "Valid fins a %s",
    "Import root certificate" : "Importar un certificat raiç",
    "Server-side encryption" : "Chiframent costat servidor",
    "Enable server-side encryption" : "Activar lo chiframent costat servidor",
    "Please read carefully before activating server-side encryption: " : "Legissètz aquò amb atencion abans d'activar lo chiframent :",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Un còp lo chiframent activat, los fichièrs mandats sul servidor a partir d'aqueste moment seràn emmagazinats jos forma chifrada. Es pas possible de desactivar lo chiframent que se lo modul utilizat o permet especificament, e que totas las condicions prealablas son reünidas per aquò far (per exemple la creacion d'una clau de recuperacion).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Lo chiframent sol pòt pas garantir la seguretat del sistèma. Consultatz la documentacion ownCloud per comprene cossí fonciona l'aplicacion de chiframent, e los cases d'utilizacion preses en carga.",
    "Be aware that encryption always increases the file size." : "Notatz que lo chiframent aumenta totjorn la talha dels fichièrs.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es oportun de salvar regularament vòstras donadas. Se aquestas donadas son chifradas, doblidetz pas de salvar tanben las claus de chiframent.",
    "This is the final warning: Do you really want to enable encryption?" : "Darrièr avertiment : Sètz segur que volètz activar lo chiframent ?",
    "Enable encryption" : "Activar lo chiframent",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Cap de modul de chiframent es pas cargat. Mercé d'activar un modul de chiframent dins lo menú de las aplicacions.",
    "Select default encryption module:" : "Seleccionatz lo modul de chiframent per defaut :",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vos cal migrar vòstras claus de chiframent de l'anciana version (ownCloud <= 8.0) cap a la novèla. Activatz \"ownCloud Default Encryption Modul\" e executatz 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vos cal migrar vòstras claus de chiframent de l'anciana version (ownCloud <= 8.0) cap a la novèla.",
    "Start migration" : "Aviar la migracion",
    "Sharing" : "Partiment",
    "Allow apps to use the Share API" : "Autorizar las aplicacions a utilizar l'API de partiment",
    "Allow users to share via link" : "Autorizar los utilizaires a partejar per ligam",
    "Allow public uploads" : "Autorizar los mandadisses publics",
    "Enforce password protection" : "Obligar la proteccion per senhal",
    "Set default expiration date" : "Especificar la data d'expiracion per defaut",
    "Allow users to send mail notification for shared files" : "Autorizar los utilizaires a mandar de notificacions per corrièl a prepaus dels partiments",
    "Expire after " : "Expiracion aprèp ",
    "days" : "jorns",
    "Enforce expiration date" : "Impausar la data d'expiracion",
    "Allow resharing" : "Autorizar lo re-partiment",
    "Restrict users to only share with users in their groups" : "Autorizar pas los partiments qu'entre membres de meteisses gropes",
    "Allow users to send mail notification for shared files to other users" : "Autorizar los utilizaires a mandar una notificacion per corrièl a prepaus dels fichièrs partejats",
    "Exclude groups from sharing" : "Empachar certans gropes de partejar",
    "These groups will still be able to receive shares, but not to initiate them." : "Aqueles gropes poiràn pas mai iniciar cap de partiment, mas poiràn totjorn rejónher los partiments faches per d'autres. ",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Lo verrolhatge transaccional de fichièrs utiliza la banca de donadas. Per obténer de  performàncias melhoras, es recomandat d'utilizar puslèu memcache. Consultatz la <a target=\"_blank\" href=\"%s\">documentacion ↗</a> per mai d'informacions.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (errors fatalas, errors, avertiments, informacions, desbugatge)",
    "Info, warnings, errors and fatal issues" : "Informacions, avertiments, errors e errors fatalas",
    "Warnings, errors and fatal issues" : "Avertiments, errors e errors fatalas",
    "Errors and fatal issues" : "Errors e errors fatalas",
    "Fatal issues only" : "Errors fatalas unicament",
    "Log" : "Log",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "La talha del fichièr jornal excedís 100 Mo. Lo telecargar pòt prene un certan temps!",
    "None" : "Pas cap",
    "Login" : "Login",
    "Plain" : "En clar",
    "NT LAN Manager" : "Gestionari de la ret NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor mail",
    "This is used for sending out notifications." : "Aquò es utilizat pel mandadís de las notificacions.",
    "Send mode" : "Mòde de mandadís",
    "Encryption" : "Chiframent",
    "From address" : "Adreça font",
    "mail" : "mail",
    "Authentication method" : "Metòde d'autentificacion",
    "Authentication required" : "Autentificacion requesida",
    "Server address" : "Adreça del servidor",
    "Port" : "Pòrt",
    "Credentials" : "Informacions d'identificacion",
    "SMTP Username" : "Nom d'utilizaire SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Store credentials" : "Enregistrar los identificants",
    "Test email settings" : "Testar los paramètres e-mail",
    "Send email" : "Mandar un mail",
    "Security & setup warnings" : "Avertiments de seguretat & configuracion",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "sembla que php es pas configurat de manièra a recuperar las valors de las variablas d’environament. Lo test de la comanda getenv(\"PATH\") torna solament una responsa voida. ",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuracion es en mòde lectura sola. Aquò empacha la modificacion de certanas configuracions via l'interfàcia web. Amai, lo fichièr deu èsser passat manualament en lectura-escritura per cada mesa a jorn.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP es aparentament configurat per suprimir los blòts de documentacion intèrnes. Aquò rendrà mantuna aplicacion de basa inaccessiblas.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La rason es probablament l'utilizacion d'un escondedor / accelerador tal coma Zend OPcache o eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Lo modul PHP 'fileinfo' es mancant. Es bravament recomandat de l'activar per fin d'obténer de melhors resultats de deteccion mime-type.",
    "System locale can not be set to a one which supports UTF-8." : "Los paramètres regionals pòdon pas èsser configurats amb presa en carga d'UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Aquò significa qu'i poiriá aver de problèmas amb certans caractèrs dins los noms de fichièr.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Vos recomandam d'installar sus vòstre sistèma los paquets requesits a la presa en carga d'un dels paramètres regionals seguents : %s",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Se vòstra installacion es pas estada efectuada a la raiç del domeni e qu'utiliza lo cron del sistèma, i pòt aver de problèmas amb la generacion d'URL. Per los evitar, configuratz l'opcion \"overwrite.cli.url\" de vòstre fichièr config.php amb lo camin de la raiç de vòstra installacion (suggerit : \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite es actualament utilizat coma gestionari de banca de donadas. Per d'installacions mai voluminosas, vos conselham d'utilizar un autre gestionari de banca de donadas.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "L'utilizacion de SQLite es particularament desconselhada se utilizatz lo client de burèu per sincronizar vòstras donadas.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Lo prètzfach cron a pas pogut s'executar via CLI. Aquelas errors tecnicas son aparegudas :",
    "All checks passed." : "Totes los tèsts an capitat.",
    "Tips & tricks" : "Estècs e astúcias",
    "How to do backups" : "Cossí far de salvaments",
    "Advanced monitoring" : "Susvelhança avançada",
    "Performance tuning" : "Ajustament de las performàncias",
    "Improving the config.php" : "Melhorament del config.php ",
    "Theming" : "Personalizacion de l'aparéncia",
    "Hardening and security guidance" : "Guida pel renforçament e la seguretat",
    "Get the apps to sync your files" : "Obtenètz las aplicacions de sincronizacion de vòstres fichièrs",
    "Desktop client" : "Client de burèu",
    "Android app" : "Aplicacion Android",
    "iOS app" : "Aplicacion iOS",
    "Show First Run Wizard again" : "Reveire la fenèstra d'acuèlh afichada al moment de vòstra primièra connexion",
    "Profile picture" : "Fòto de perfil",
    "Upload new" : "Novèla dempuèi vòstre ordenador",
    "Remove image" : "Suprimir l'imatge",
    "Cancel" : "Anullar",
    "Full name" : "Nom complet",
    "No display name set" : "Cap de nom d'afichatge pas configurat",
    "Email" : "Adreça mail",
    "Your email address" : "Vòstra adreça mail",
    "No email address set" : "Cap d'adreça e-mail pas configurada",
    "You are member of the following groups:" : "Sètz membre dels gropes seguents :",
    "Password" : "Senhal",
    "Unable to change your password" : "Impossible de cambiar vòstre senhal",
    "Current password" : "Senhal actual",
    "New password" : "Senhal novèl",
    "Change password" : "Cambiar de senhal",
    "Language" : "Lenga",
    "Help translate" : "Ajudatz a tradusir",
    "Unlimited" : "Illimitat",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Desvolopat per la {communityopen}comunautat ownCloud{linkclose}, lo {githubopen}code font{linkclose} es jos licéncia {licenseopen}<abbr lang=\"en\" title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Name" : "Nom",
    "Username" : "Nom d'utilizaire",
    "Version" : "Version",
    "Personal" : "Personal",
    "Admin" : "Administracion",
    "Error" : "Error",
    "Show storage location" : "Afichar l'emplaçament de l'emmagazinatge",
    "Show last log in" : "Far veire la darrièra connexion",
    "Show user backend" : "Far veire la font de l'identificant",
    "Send email to new user" : "Mandar un corrièl als utilizaires creats",
    "Show email address" : "Afichar l'adreça email",
    "E-Mail" : "Corrièl",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperacion del senhal administrator",
    "Enter the recovery password in order to recover the users files during password change" : "Entratz lo senhal de recuperacion per recuperar los fichièrs utilizaires pendent lo cambiament de senhal",
    "Add Group" : "Apondre un grop",
    "Group" : "Grop",
    "Everyone" : "Tot lo monde",
    "Admins" : "Administrators",
    "Default Quota" : "Quòta per defaut",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Entratz lo quòta d'emmagazinatge (ex. \"512 MB\" o \"12 GB\")",
    "Other" : "Autre",
    "Full Name" : "Nom complet",
    "Group Admin for" : "Administrator de grop per",
    "Quota" : "Quòta",
    "Storage Location" : "Emplaçament de l'Emmagazinatge",
    "User Backend" : "Font",
    "Last Login" : "Darrièra Connexion",
    "change full name" : "Modificar lo nom complet",
    "set new password" : "Cambiar lo senhal",
    "change email address" : "cambiar l'adreça email",
    "Default" : "Defaut",
    "Share" : "Partejar",
    "Domain" : "Domeni",
    "Add" : "Apondre"
},
"nplurals=2; plural=(n > 1);");
